pub struct CommitUploadSession<'a> {
pub(crate) http_client: HttpClientRef,
pub session_id: &'a Uuid,
chapter_draft: ChapterDraft<'a>,
pub page_order: Vec<Uuid>,
}Fields
http_client: HttpClientRefThis should never be set manually as this is only for internal use.
session_id: &'a Uuidchapter_draft: ChapterDraft<'a>page_order: Vec<Uuid>Ordered list of Upload Session File IDs.
Any uploaded files that are not included in this list will be deleted.
Implementations
Sourceimpl CommitUploadSession<'_>
impl CommitUploadSession<'_>
Sourcepub async fn send(&self) -> Result<ChapterObject>
pub async fn send(&self) -> Result<ChapterObject>
Send the request.